fn completion_key(item: &ImportAttainmentRequestItem) -> StringExpand description
Suotar’s intra-batch duplicate key. The enrolment and the language are deliberately not in it.
fn completion_key(item: &ImportAttainmentRequestItem) -> StringSuotar’s intra-batch duplicate key. The enrolment and the language are deliberately not in it.