endpoint_handlers

Macro endpoint_handlers 

macro_rules! endpoint_handlers {
    ($($handler:ident => $endpoint:ident,)*) => { ... };
}
Actix binds one handler per route, so the endpoint each route serves is all these differ by.