macro_rules! endpoint_handlers {
($($handler:ident => $endpoint:ident,)*) => { ... };
}Expand description
Actix binds one handler per route, so the endpoint each route serves is all these differ by.
macro_rules! endpoint_handlers {
($($handler:ident => $endpoint:ident,)*) => { ... };
}Actix binds one handler per route, so the endpoint each route serves is all these differ by.